Structure factor and scattering from radial distribution functions
==================================================================
Please see [the examples](https://gitlab.com/asod/grsq/-/blob/main/examples/examples.ipynb) for information on how to use. 


### Copyright

Copyright (c) 2022, Asmus Ougaard Dohn

